@@ -2,11 +2,15 @@ package MyCPAN::Indexer::Interface::Curses;
 use strict;
 use warnings;
 
-use Log::Log4perl;
-use Curses;
+BEGIN {
+	my $rc = eval { require Curses; 1 };
+
+	die "You need to install the Curses module to use MyCPAN::Indexer::Interface::Curses";
+	Curses->import;
+}
 
 use vars qw($VERSION $logger);
-$VERSION = '1.17_02';
+$VERSION = '1.17_04';
 
 =head1 NAME
 
@@ -35,24 +39,25 @@ This class presents the information as the indexer runs, using Curses.
 BEGIN { $SIG{INT} = sub { exit } }
 
 BEGIN {
+	use Log::Log4perl;
 	$logger = Log::Log4perl->get_logger( 'Interface' );
 	}
 
-sub do_interface 
+sub do_interface
 	{
 	my( $class, $Notes ) = @_;
 	$logger->debug( "Calling do_interface" );
-	
+
 	initscr();
 	noecho();
 	raw();
-	
+
 	$Notes->{curses}{rows} = LINES();
 	$Notes->{curses}{cols} = COLS();
-	
-	addstr( 0, 0, 'BackPAN Indexer 1.00' );	
+
+	addstr( 0, 0, 'BackPAN Indexer 1.00' );
 	refresh();
-	
+
 	$Notes->{curses}{windows}{progress}      = newwin( 3, COLS(),   1,  0 );
 	$Notes->{curses}{windows}{left_tracker}  = newwin( 6, 20,   4,  0 );
 	$Notes->{curses}{windows}{right_tracker} = newwin( 6, COLS() - 21,   4, 21 );
@@ -64,14 +69,14 @@ sub do_interface
 		box( $value, 0, 0 );
 		refresh( $value );
 		}
-		
+
 	my $count = 0;
 	while( 1 )
 		{
 		$Notes->{interface_callback}->();
 
 		_update_screen( $Notes );
-		
+
 		last if $Notes->{Left} <= 0;
 		}
 
@@ -85,13 +90,13 @@ my $labels = {
 	Done       => [ qw(left_tracker  2  1 Done          6   6) ],
 	Left       => [ qw(left_tracker  3  1 Left          6   6) ],
 	Errors     => [ qw(left_tracker  4  1 Errors        6   6) ],
-	
+
 	UUID       => [ qw(right_tracker 1  1 UUID          8  30) ],
 	Started    => [ qw(right_tracker 2  1 Started       8 -30) ],
 	Elapsed    => [ qw(right_tracker 3  1 Elapsed       8 -30) ],
 	Rate       => [ qw(right_tracker 4  1 Rate          8 -30) ],
 	};
-	
+
 my $headers = {
 	'##'       => [ qw(PID           1  1 ##            2   0) ],
 	PID        => [ qw(PID           1  5 PID           6   0) ],
@@ -108,20 +113,20 @@ sub _update_screen
 	&_update_progress;
 	&_update_values;
 	}
-	
+
 sub _update_labels
 	{
 	my( $Notes ) = @_;
-	
+
 	#print "Calling _update_screen\n";
-	
+
 	foreach my $key ( keys %$labels )
 		{
 		my $tuple = $labels->{$key};
-		
-		eval { addstr( 
+
+		eval { addstr(
 			$Notes->{curses}{windows}{ $tuple->[0] },
-			@$tuple[1,2,3] 
+			@$tuple[1,2,3]
 			);
 		refresh( $Notes->{curses}{windows}{ $tuple->[0] } );
 		};
@@ -130,11 +135,11 @@ sub _update_labels
 	foreach my $key ( keys %$headers )
 		{
 		my $tuple = $headers->{$key};
-		
-		eval { 
-		
+
+		eval {
+
 		my $width = $tuple->[4];
-		addstr( 
+		addstr(
 			$Notes->{curses}{windows}{ $tuple->[0] },
 			@$tuple[1,2],
 			sprintf "%${width}s", $tuple->[3]
@@ -148,10 +153,10 @@ sub _update_labels
 		{
 		no warnings;
 		my $width = $headers->{'##'}[4];
-		addstr( 
+		addstr(
 			$Notes->{curses}{windows}{PID},
-			$i + 1, 
-			$headers->{'##'}[2] + 1, 
+			$i + 1,
+			$headers->{'##'}[2] + 1,
 			sprintf "%${width}s", $i );
 		refresh( $Notes->{curses}{windows}{PID} );
 		}
@@ -164,29 +169,29 @@ sub _update_progress
 	my( $Notes ) = @_;
 
 	my $progress = eval { ( COLS() - 2 ) / $Notes->{Total} * $Notes->{Done} } || 0;
-	
-	addstr( 
-		$Notes->{curses}{windows}{progress}, 
+
+	addstr(
+		$Notes->{curses}{windows}{progress},
 		1, 1,
-		'*' x $progress 
+		'*' x $progress
 		);
-	refresh( $Notes->{curses}{windows}{progress} );	
+	refresh( $Notes->{curses}{windows}{progress} );
 	}
-	
+
 sub _update_values
 	{
 	my( $Notes ) = @_;
-		
+
 	no warnings;
 	foreach my $key ( qw(Total Done Left Errors UUID Started Elapsed Rate) )
 		{
 		my $tuple = $labels->{$key};
 
-		addstr( 
+		addstr(
 			$Notes->{curses}{windows}{ $tuple->[0] },
-			$tuple->[1], 
-			$tuple->[2] + $tuple->[4] + 2, 
-			sprintf "%" . $tuple->[5] . "s", $Notes->{$tuple->[3]} 
+			$tuple->[1],
+			$tuple->[2] + $tuple->[4] + 2,
+			sprintf "%" . $tuple->[5] . "s", $Notes->{$tuple->[3]}
 			);
 		refresh( $Notes->{curses}{windows}{ $tuple->[0] } );
 		}
@@ -194,27 +199,27 @@ sub _update_values
 	foreach my $i ( 1 .. $Notes->{Threads} )
 		{
 		my $width = $headers->{PID}[4];
-		addstr( 
+		addstr(
 			$Notes->{curses}{windows}{PID},
-			$i + 1, $headers->{PID}[2], 
-			sprintf "%${width}s", $Notes->{PID}[$i-1] 
+			$i + 1, $headers->{PID}[2],
+			sprintf "%${width}s", $Notes->{PID}[$i-1]
 			);
 
 		$width = COLS() - $headers->{Processing}[2] - 1;
-		addstr( 
+		addstr(
 			$Notes->{curses}{windows}{PID},
-			$i + 1, 
-			$headers->{Processing}[2], 
+			$i + 1,
+			$headers->{Processing}[2],
 			' ' x ( COLS() - $headers->{Processing}[2] - 1 )
 			);
-		addstr( 
+		addstr(
 			$Notes->{curses}{windows}{PID},
-			$i + 1, 
-			$headers->{Processing}[2], 
-			sprintf "%-${width}s", substr( 
+			$i + 1,
+			$headers->{Processing}[2],
+			sprintf "%-${width}s", substr(
 				(defined $Notes->{recent}[$i-1] ? $Notes->{recent}[$i-1] : ''), 0, $width )
 			);
-				
+
 		refresh( $Notes->{curses}{windows}{PID} );
 		}
 
