@@ -3,8 +3,9 @@ use strict;
 use warnings;
 
 use vars qw($VERSION $logger);
-$VERSION = '1.17_02';
+$VERSION = '1.17_04';
 
+use Cwd;
 use File::Basename;
 use File::Spec::Functions qw(catfile);
 use Log::Log4perl;
@@ -34,47 +35,51 @@ hands a disribution to for the actual indexing.
 =item get_task( $Notes )
 
 C<get_task> sets the C<child_task> key in the C<$Notes> hash reference. The
-value is a code reference that takes a distribution path as its only 
+value is a code reference that takes a distribution path as its only
 argument and indexes that distribution.
 
 See L<MyCPAN::Indexer::Tutorial> for details about what C<get_task> expects
 and should do.
 
 =cut
-   
+
 BEGIN {
 	$logger = Log::Log4perl->get_logger( 'Worker' );
 	}
-	
+
 sub get_task
 	{
 	my( $class, $Notes ) = @_;
-	
+
 	$Notes->{child_task} = sub {
 		my $dist = shift;
-		
+
 		my $basename = $class->_check_for_previous_result( $dist, $Notes );
 		return unless $basename;
-		
+
 		my $Config = $Notes->{config};
-		
+
 		$logger->info( "Child process for $basename starting\n" );
-			
+
 		my $Indexer = $Config->indexer_class || 'MyCPAN::Indexer';
-		
+
 		eval "require $Indexer" or die;
+
+		my $starting_dir = cwd();
 		
 		unless( chdir $Config->temp_dir )
 			{
 			$logger->error( "Could not change to " . $Config->temp_dir . " : $!\n" );
 			exit 255;
 			}
-		
+
 		local $SIG{ALRM} = sub { die "alarm rang for $basename!\n" };
 		alarm( $Config->alarm || 15 );
 		my $info = eval { $Indexer->run( $dist ) };
 		alarm 0;
 
+		chdir $starting_dir;
+		
 		unless( defined $info )
 			{
 			$logger->error( "run failed for $basename: $@" );
@@ -91,32 +96,32 @@ sub get_task
 			}
 
 		$class->_add_run_info( $info, $Notes );
-		
+
 		$Notes->{reporter}->( $Notes, $info );
-		
+
 		$logger->debug( "Child process for $basename done" );
-		
+
 		1;
 		};
-		
+
 	}
 
 sub _copy_bad_dist
 	{
 	my( $class, $Notes, $info ) = @_;
-	
+
 	if( my $bad_dist_dir = $Notes->{config}->copy_bad_dists )
 		{
 		my $dist_file = $info->dist_info( 'dist_file' );
 		my $basename  = $info->dist_info( 'dist_basename' );
 		my $new_name  = catfile( $bad_dist_dir, $basename );
-		
+
 		unless( -e $new_name )
 			{
 			$logger->debug( "Copying bad dist" );
-			
+
 			my( $in, $out );
-			
+
 			unless( open $in, "<", $dist_file )
 				{
 				$logger->fatal( "Could not open bad dist to $dist_file: $!" );
@@ -128,34 +133,34 @@ sub _copy_bad_dist
 				$logger->fatal( "Could not copy bad dist to $new_name: $!" );
 				return;
 				}
-				
+
 			while( <$in> ) { print { $out } $_ }
 			close $in;
 			close $out;
 			}
-		}	
+		}
 	}
-	
+
 sub _check_for_previous_result
-	{	
+	{
 	my( $class, $dist, $Notes ) = @_;
-	
+
 	my $Config = $Notes->{config};
-	
+
 	( my $basename = basename( $dist ) ) =~ s/\.(tgz|tar\.gz|zip)$//;
 
 	my $yml_dir        = catfile( $Config->report_dir, "meta"        );
 	my $yml_error_dir  = catfile( $Config->report_dir, "meta-errors" );
-	
+
 	my $yml_path       = catfile( $yml_dir,       "$basename.yml" );
 	my $yml_error_path = catfile( $yml_error_dir, "$basename.yml" );
-	
+
 	if( my @path = grep { -e } ( $yml_path, $yml_error_path ) )
 		{
 		$logger->debug( "Found run output for $basename in $path[0]. Skipping...\n" );
 		return;
 		}
-		
+
 	return $basename;
 	}
 
@@ -164,19 +169,19 @@ sub _add_run_info
 	my( $class, $info, $Notes ) = @_;
 
 	my $Config = $Notes->{config};
-	
+
 	return unless eval { $info->can( 'set_run_info' ) };
-	
-	$info->set_run_info( $_, $Config->get( $_ ) ) 
+
+	$info->set_run_info( $_, $Config->get( $_ ) )
 		foreach ( $Config->directives );
-	
-	$info->set_run_info( 'uuid', $Notes->{UUID} ); 
 
-	$info->set_run_info( 'child_pid',  $$ ); 
-	$info->set_run_info( 'parent_pid', getppid ); 
+	$info->set_run_info( 'uuid', $Notes->{UUID} );
+
+	$info->set_run_info( 'child_pid',  $$ );
+	$info->set_run_info( 'parent_pid', eval { $Config->indexer_class->getppid } );
+
+	$info->set_run_info( 'ENV', \%ENV );
 
-	$info->set_run_info( 'ENV', \%ENV ); 
-	
 	return 1;
 	}
 
